@@ -16,6 +16,8 @@ from .dsmr import DSRM
 from copy import deepcopy
 from cachetools import Cache
 
+import importlib
+
 # from .plugin_localproxy import LocalProxyPlugin
 
 logger = logging.getLogger(__name__)
@@ -179,6 +181,11 @@ class DataLogger(object):
         return True
 
     def terminate(self):
+        # Cleanup Client
+        self._terminate_client()
+        # Cleanup Output plugins
+        self._terminate_output_plugins()
+        # Terminate DSMR
         if self.dsmr:
             self.dsmr.terminate()
 
@@ -197,13 +204,20 @@ class DataLogger(object):
             Client.logger = self.logger
             Client.config = self.config
             Client.hass_api = self.hass_api
-            __import__(self.client_module)
+            # __import__(self.client_module)
+            spec = importlib.util.find_spec(self.client_module)
+            module = importlib.util.module_from_spec(spec)
+            spec.loader.exec_module(module)
             self.client = Client.client[0]
         except Exception as e:
             hybridlogger.ha_log(self.logger, self.hass_api,
                                 "ERROR", f"Client '{self.client_module}' could not be initialized. Error: {e}")
             sys.exit(1)
 
+    def _terminate_client(self):
+        while Client.client:
+            Client.client.pop(0).terminate()
+
     def _init_output_plugins(self):
         self.plugins = self.config.getlist('plugins', 'output', fallback=[''])
         if self.plugins and self.plugins[0]:
@@ -218,7 +232,14 @@ class DataLogger(object):
             Plugin.hass_api = self.hass_api
 
             for plugin in self.plugins:
-                __import__(plugin)
+                spec = importlib.util.find_spec(plugin)
+                module = importlib.util.module_from_spec(spec)
+                spec.loader.exec_module(module)
+                # importlib.import_module(plugin)
+
+    def _terminate_output_plugins(self):
+        while Plugin.plugins:
+            Plugin.plugins.pop(0).terminate()
 
     def _init_dsmr(self):
         terminals = self.config.getlist('dsmr', 'terminals', fallback=[])
@@ -285,7 +306,7 @@ class DataLogger(object):
             self._dsmr_cache_update(plant_id, dsmr_message)
             # self.dsmr_data[plant_id] = deepcopy(dsmr_message)
             self.dsmr_access.release()
-            if plant_id in self.plant_update and self.total_energy(plant_id):
+            if plant_id in self.plant_update:
                 self._proces_pushed_net_event(plant_id, dsmr_message)
         else:
             self._proces_pushed_net_event(None, dsmr_message)
@@ -682,7 +703,7 @@ class DataLogger(object):
         data = deepcopy(dsmr_message)
         dsmr_timestamp = data['timestamp']
         # if (dsmr_timestamp - last_update) > (self.every + 10) and dsmr_timestamp > self.pasttime:
-        if dsmr_timestamp > self.pasttime and plant_id:
+        if dsmr_timestamp > self.pasttime and plant_id and self.total_energy(plant_id):
             # Process independent net data for aggregated clients with regards of rate limits
             # data['current_power'] = Decimal('0')
             # Omnik related fields need 'last_update' timestamp
